@@ -24,7 +24,6 @@ use fields (
     'rq_version',   # version of request
     'rp_encoder',   # sub to encode response body (chunked)
     'keep_alive',   # do we use keep_alive in response
-
 );
 
 use App::HTTP_Proxy_IMP::Debug qw(debug $DEBUG debug_context);
@@ -84,6 +83,19 @@ sub fatal {
     }
 }
 
+sub deny {
+    my ($self,$reason) = @_;
+    warn "[deny] ".$self->id." $reason\n";
+    if ( my $conn = $self->{conn} ) {
+        my $relay =  $conn->{relay};
+        $relay->account(%{ $self->{meta}}, %{ $self->{acct}}, 
+	    status => 'DENIED', reason => $reason );
+	$relay->forward(1,0,"HTTP/1.0 403 $reason\r\n\r\n") 
+	   if ! $self->{acct}{code};
+	$relay->close;
+    }
+}
+
 sub xtrace {
     my $self = shift;
     my $msg = shift;
